#[non_exhaustive]pub struct ListWorkGroupsOutput {
pub work_groups: Option<Vec<WorkGroupSummary>>,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.work_groups: Option<Vec<WorkGroupSummary>>A list of WorkGroupSummary objects that include the names, descriptions, creation times, and states for each workgroup.
next_token: Option<String>A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Implementations
Sourceimpl ListWorkGroupsOutput
impl ListWorkGroupsOutput
Sourcepub fn work_groups(&self) -> &[WorkGroupSummary]
pub fn work_groups(&self) -> &[WorkGroupSummary]
A list of WorkGroupSummary objects that include the names, descriptions, creation times, and states for each workgroup.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .work_groups.is_none().
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
A token generated by the Athena service that specifies where to continue pagination if a previous request was truncated. To obtain the next set of pages, pass in the NextToken from the response object of the previous page call.
Sourceimpl ListWorkGroupsOutput
impl ListWorkGroupsOutput
Sourcepub fn builder() -> ListWorkGroupsOutputBuilder
pub fn builder() -> ListWorkGroupsOutputBuilder
Creates a new builder-style object to manufacture ListWorkGroupsOutput.